@@ -111,6 +111,12 @@ MainWindow::MainWindow()
     // The "Create" flag will make it call createGUI()
     setupGUI(guiOpts, xmlFile);
 
+    // Hamburger menu for when the menubar is hidden
+    _hamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, actionCollection());
+    _hamburgerMenu->setShowMenuBarAction(_toggleMenuBarAction);
+    _hamburgerMenu->setMenuBar(menuBar());
+    connect(_hamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, &MainWindow::updateHamburgerMenu);
+
     // remember the original menu accelerators for later use
     rememberMenuAccelerators();
 
@@ -205,6 +211,12 @@ void MainWindow::correctStandardShortcuts()
     if (helpAction != nullptr) {
         actionCollection()->setDefaultShortcut(helpAction, QKeySequence());
     }
+
+    // replace F10 shortcut for main menu to pass F10 key to the console application
+    QAction *openMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
+    if (openMenu != nullptr) {
+        actionCollection()->setDefaultShortcut(openMenu, QKeySequence(Qt::SHIFT | Qt::Key_F10));
+    }
 }
 
 ViewManager *MainWindow::viewManager() const
@@ -370,7 +382,11 @@ void MainWindow::setupActions()
     });
 
     // Set up themes
+#if KCOLORSCHEME_VERSION < QT_VERSION_CHECK(6, 6, 0)
     auto *manager = new KColorSchemeManager(actionCollection());
+#else
+    auto *manager = KColorSchemeManager::instance();
+#endif
     manager->setAutosaveChanges(true);
     KActionMenu *selectionMenu = KColorSchemeMenu::createMenu(manager, this);
     auto winColorSchemeMenu = new QAction(this);
@@ -415,12 +431,6 @@ void MainWindow::setupActions()
             viewManager()->loadLayoutFile();
         }
     });
-
-    // Hamburger menu for when the menubar is hidden
-    _hamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, collection);
-    _hamburgerMenu->setShowMenuBarAction(_toggleMenuBarAction);
-    _hamburgerMenu->setMenuBar(menuBar());
-    connect(_hamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, &MainWindow::updateHamburgerMenu);
 }
 
 void MainWindow::updateHamburgerMenu()
