@@ -78,10 +78,39 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session,
         int delta = forwards ? maxDelta : -maxDelta;
 
         int endLine = line;
+        bool continueLoop = true;
+        bool invertDirection = false;
         bool hasWrapped = false; // set to true when we reach the top/bottom
         // of the output and continue from the other
         // end
 
+        QSet<int> matchPositions;
+
+        decoder.begin(&searchStream);
+        emulation->writeToStream(&decoder, 0, lastLine);
+        decoder.end();
+
+        QRegularExpressionMatchIterator matchIterator = _regExp.globalMatch(string);
+        while (matchIterator.hasNext()) {
+            QRegularExpressionMatch match = matchIterator.next();
+            int pos = match.capturedStart();
+            if (pos != -1) {
+                int newLines = 0;
+                QList<int> linePositions = decoder.linePositions();
+                while (newLines < linePositions.count() && linePositions[newLines] <= pos) {
+                    newLines++;
+                }
+                newLines--;
+
+                int findPos = qMin(0, lastLine) + newLines;
+                matchPositions.insert(findPos);
+            }
+        }
+
+        Q_EMIT searchResults(matchPositions, window->lineCount());
+
+        string.clear();
+
         // loop through history in blocks of <delta> lines.
         do {
             // ensure that application does not appear to hang
@@ -99,9 +128,15 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session,
                 endLine += delta;
 
                 if (forwards) {
-                    endLine = qMin(startLine, endLine);
+                    if (endLine >= startLine) {
+                        endLine = startLine;
+                        continueLoop = false;
+                    }
                 } else {
-                    endLine = qMax(startLine, endLine);
+                    if (endLine <= startLine) {
+                        endLine = startLine;
+                        continueLoop = false;
+                    }
                 }
             } else {
                 endLine += delta;
@@ -150,7 +185,11 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session,
 
             // if noWrap is checked and we wrapped, set cursor at last match
             if (hasWrapped && _noWrap) {
-                // invert search direction
+                // one chance to invert search direction
+                if (invertDirection) {
+                    continueLoop = false;
+                }
+                invertDirection = true;
                 forwards = !forwards;
                 delta = -delta;
                 endLine += (forwards ? 1 : -1);
@@ -160,11 +199,13 @@ void SearchHistoryTask::executeOnScreenWindow(const QPointer<Session> &session,
             // clear the current block of text and move to the next one
             string.clear();
             line = endLine;
-        } while (startLine != endLine);
+        } while (continueLoop);
         if (!session->getSelectMode()) {
             // if no match was found, clear selection to indicate this,
             window->clearSelection();
             window->notifyOutputChanged();
+
+            Q_EMIT searchResults(QSet<int>{}, window->lineCount());
         }
     }
 
