@@ -70,17 +70,15 @@ public:
      *
      * @param table Array into which the color entries for this color scheme
      * are copied.
-     * @param randomSeed Color schemes may allow certain colors in their
-     * palette to be randomized.  The seed is used to pick the random color.
      */
-    void getColorTable(QColor *table, uint randomSeed = 0) const;
+    void getColorTable(QColor *table, uint sessionId = 0) const;
 
     /**
      * Retrieves a single color entry from the table.
      *
      * See getColorTable()
      */
-    QColor colorEntry(int index, uint randomSeed = 0) const;
+    QColor colorEntry(int index, uint sessionId = 0) const;
 
     /**
      * Convenience method.  Returns the
