@@ -14,17 +14,9 @@
 
 namespace Konsole
 {
-HighlightScrolledLines::HighlightScrolledLines()
-    : _enabled(false)
-    , _previousScrollCount(0)
-    , _timer(nullptr)
-    , _needToClear(false)
-{
-}
+HighlightScrolledLines::HighlightScrolledLines() = default;
 
-HighlightScrolledLines::~HighlightScrolledLines()
-{
-}
+HighlightScrolledLines::~HighlightScrolledLines() = default;
 
 bool HighlightScrolledLines::isEnabled()
 {
@@ -36,16 +28,6 @@ void HighlightScrolledLines::setEnabled(bool enable)
     _enabled = enable;
 }
 
-bool HighlightScrolledLines::isNeedToClear()
-{
-    return _needToClear;
-}
-
-void HighlightScrolledLines::setNeedToClear(bool isNeeded)
-{
-    _needToClear = isNeeded;
-}
-
 int HighlightScrolledLines::getPreviousScrollCount()
 {
     return _previousScrollCount;
