@@ -188,6 +188,9 @@ private Q_SLOTS:
     void toggleScrollbarMarkerColor(QColor color);
     void toggleScrollbarMarkerSize(double pSize);
 
+    void toggleScrollbarSearchLineColor(QColor color);
+    void toggleScrollbarSearchLineOpacity(int opacity);
+
     // keyboard page
     void editKeyBinding();
     void newKeyBinding();
@@ -220,8 +223,9 @@ private Q_SLOTS:
     void toggleFlowControl(bool);
     void updateUrlHintsModifier(bool);
     void toggleReverseUrlHints(bool);
+    void setAutoSaveInterval(int);
 
-    void setDefaultCodec(QTextCodec *);
+    void setDefaultCodec(const QByteArray &codec);
 
     void setTextEditorCombo(const Profile::Ptr &profile);
 
